@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2008, 2010, 2011 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2008, 2010, 2011, 2012 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +49,10 @@
 #include <cstdlib>
 #include <ctime>
 
+#ifndef GL_CLAMP_TO_EDGE
+#define GL_CLAMP_TO_EDGE 0x812F
+#endif
+
 //-----------------------------------------------------------------------------
 
 int powerOfTwo(int value)
@@ -606,7 +610,9 @@ void Board::paintGL()
 	// Draw scene rectangle
 	QColor fill = palette().color(QPalette::Base);
 	QColor border = fill.lighter(125);
-	drawArray(m_scene_array, fill, border);
+	if (m_scene.isValid()) {
+		drawArray(m_scene_array, fill, border);
+	}
 
 	// Draw pieces
 	graphics_layer->bindTexture(0, m_image);
@@ -1143,6 +1149,8 @@ void Board::loadImage()
 		QPainter painter(&texture);
 		painter.drawImage(0, 0, image, 0, 0, image.width(), image.height(), Qt::AutoColor | Qt::AvoidDither);
 	}
+	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
+	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
 	m_image = bindTexture(texture, GL_TEXTURE_2D, GL_RGBA, QGLContext::LinearFilteringBindOption | QGLContext::MipmapBindOption);
 
 	// Create corners
@@ -1232,10 +1240,10 @@ void Board::updateArray(VertexArray& array, const QRect& rect, int z)
 	int y2 = y1 + rect.height();
 
 	QVector<Vertex> verts;
-	verts.append( Vertex(x1,y1,z) );
-	verts.append( Vertex(x1,y2,z) );
-	verts.append( Vertex(x2,y2,z) );
-	verts.append( Vertex(x2,y1,z) );
+	verts.append( Vertex::init(x1,y1,z) );
+	verts.append( Vertex::init(x1,y2,z) );
+	verts.append( Vertex::init(x2,y2,z) );
+	verts.append( Vertex::init(x2,y1,z) );
 	graphics_layer->updateArray(array, verts);
 }
 
@@ -1310,7 +1318,7 @@ void Board::finishGame()
 	emit retrievePiecesAvailable(false);
 
 	QFile::remove(Path::save(m_id));
-	QSettings().remove("OpenGame/Image");
+	QSettings().remove("OpenGame");
 	m_id = 0;
 
 	emit finished();
@@ -1343,7 +1351,7 @@ void Board::cleanup()
 	m_pos = QPoint(0, 0);
 	m_finished = false;
 
-	QSettings().remove("OpenGame/Image");
+	QSettings().remove("OpenGame");
 }
 
 //-----------------------------------------------------------------------------
