@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2008, 2010, 2011 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2008, 2010, 2011, 2012, 2013 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ Application::Application(int& argc, char** argv)
 	m_window(0)
 {
 	setApplicationName("Tetzle");
-	setApplicationVersion("2.0.1");
+	setApplicationVersion(VERSIONSTR);
 	setOrganizationDomain("gottcode.org");
 	setOrganizationName("GottCode");
 	{
@@ -73,6 +73,14 @@ Application::Application(int& argc, char** argv)
 
 void Application::createWindow()
 {
+	// Remove command-line parameters from file list
+	for (int i = 0; i < m_files.size(); ++i) {
+		if (m_files.at(i).startsWith("--")) {
+			m_files.removeAt(i);
+			--i;
+		}
+	}
+
 	m_window = new Window(m_files);
 }
 
@@ -117,25 +125,38 @@ int main(int argc, char** argv)
 	// Load application language
 	LocaleDialog::loadTranslator("tetzle_");
 
-	// Update data location
+	// Create data location
 	QString path = Path::datapath();
 	if (!QFile::exists(path)) {
-#if defined(Q_OS_MAC)
-		QString oldpath = QDir::homePath() + "/Library/Application Support/GottCode/Tetzle/";
-#elif defined(Q_OS_UNIX)
-		QString oldpath = getenv("$XDG_DATA_HOME");
-		if (oldpath.isEmpty()) {
-			oldpath = QDir::homePath() + "/.local/share/";
-		}
-		oldpath += "/games/tetzle/";
-#elif defined(Q_OS_WIN32)
-		QString oldpath = QDir::homePath() + "/Application Data/GottCode/Tetzle/";
-#endif
-		if (!QFile::exists(oldpath)) {
-			dir = QDir::home();
-			dir.mkpath(path);
-		} else {
-			QFile::rename(oldpath, path);
+		QDir dir(path);
+		dir.mkpath(dir.absolutePath());
+
+		// Migrate data from old location
+		QString oldpath = Path::oldDataPath();
+		if (QFile::exists(oldpath)) {
+			QStringList old_dirs = QStringList() << "";
+
+			QDir olddir(oldpath);
+			for (int i = 0; i < old_dirs.count(); ++i) {
+				QString subpath = old_dirs.at(i);
+				dir.mkpath(path + "/" + subpath);
+				olddir.setPath(oldpath + "/" + subpath);
+
+				QStringList subdirs = olddir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
+				foreach (const QString& subdir, subdirs) {
+					old_dirs.append(subpath + "/" + subdir);
+				}
+
+				QStringList files = olddir.entryList(QDir::Files);
+				foreach (const QString& file, files) {
+					QFile::rename(olddir.absoluteFilePath(file), path + "/" + subpath + "/" + file);
+				}
+			}
+
+			olddir.setPath(oldpath);
+			for (int i = old_dirs.count() - 1; i >= 0; --i) {
+				olddir.rmdir(oldpath + "/" + old_dirs.at(i));
+			}
 		}
 	}
 	dir.setPath(path);
