@@ -70,7 +70,7 @@
     <message>
         <location filename="../src/board.cpp" line="194"/>
         <location filename="../src/board.cpp" line="269"/>
-        <location filename="../src/main.cpp" line="146"/>
+        <location filename="../src/main.cpp" line="167"/>
         <source>Please Wait</source>
         <translation>Bitte warten</translation>
     </message>
@@ -336,7 +336,7 @@ Es existieren gespeicherte Spiele, die dieses Bild benutzen und die ebenfalls ge
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/main.cpp" line="147"/>
+        <location filename="../src/main.cpp" line="168"/>
         <location filename="../src/window.cpp" line="50"/>
         <location filename="../src/window.cpp" line="286"/>
         <source>Tetzle</source>
@@ -450,12 +450,12 @@ Es existieren gespeicherte Spiele, die dieses Bild benutzen und die ebenfalls ge
     <message>
         <location filename="../src/window.cpp" line="123"/>
         <source>&amp;About</source>
-        <translation>&amp;Info</translation>
+        <translation>Ü&amp;ber</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="125"/>
         <source>About &amp;Qt</source>
-        <translation>Info über &amp;Qt</translation>
+        <translation>Über &amp;Qt</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="252"/>
@@ -531,12 +531,12 @@ Es existieren gespeicherte Spiele, die dieses Bild benutzen und die ebenfalls ge
     <message>
         <location filename="../src/window.cpp" line="285"/>
         <source>About Tetzle</source>
-        <translation>Info über Tetzle</translation>
+        <translation>Über Tetzle</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="287"/>
         <source>A jigsaw puzzle with tetrominoes for pieces</source>
-        <translation>Eine Puzzlespiel mit Tetrominos als Puzzleteilen</translation>
+        <translation>Ein Puzzlespiel mit Tetrominos als Puzzleteile</translation>
     </message>
     <message>
         <location filename="../src/window.cpp" line="288"/>
